@@ -131,6 +131,7 @@ class CLIParser:
                 "resize",
                 "cloudwizard",
                 "follow",
+                "list",
             ]
         ):
             parser.add_argument(
@@ -162,6 +163,32 @@ class CLIParser:
                 metavar="<tag>",
             )
 
+        # Namespace and tag attributes are defaulted to "" when using 'yd-list'
+        if any(module in sys.argv[0] for module in ["list"]):
+            parser.add_argument(
+                "--namespace",
+                "-n",
+                type=str,
+                required=False,
+                nargs="?",
+                const="",
+                default="",
+                help="the namespace to search when listing entities",
+                metavar="<namespace>",
+            )
+            parser.add_argument(
+                "--tag",
+                "-t",
+                "--prefix",
+                type=str,
+                required=False,
+                nargs="?",
+                const="",
+                default="",
+                help="the tag to search when listing entities",
+                metavar="<tag>",
+            )
+
         if any(module in sys.argv[0] for module in ["submit"]):
             parser.add_argument(
                 "--work-requirement",
